<?php
class BackupHandler {
    private $db;
    private $backupDir;
    
    public function __construct($db) {
        $this->db = $db;
        $this->backupDir = dirname(__FILE__) . '/../../backups/';
        
        if (!file_exists($this->backupDir)) {
            mkdir($this->backupDir, 0755, true);
        }
    }
    
    public function createBackup($type = 'manual') {
        try {
            $filename = 'backup_' . date('Y-m-d_H-i-s') . '.sql';
            $filepath = $this->backupDir . $filename;
            
            // إنشاء نسخة احتياطية من قاعدة البيانات
            $this->backupDatabase($filepath);
            
            // تسجيل النسخة الاحتياطية في قاعدة البيانات
            $size = filesize($filepath);
            $this->logBackup($filename, $size, $type);
            
            return true;
        } catch (Exception $e) {
            error_log("Backup Error: " . $e->getMessage());
            return false;
        }
    }
    
    private function backupDatabase($filepath) {
        $tables = [];
        $result = $this->db->query("SHOW TABLES");
        while ($row = $result->fetch(PDO::FETCH_NUM)) {
            $tables[] = $row[0];
        }
        
        $output = "-- النسخة الاحتياطية لنظام المقاولات\n";
        $output .= "-- تاريخ: " . date('Y-m-d H:i:s') . "\n\n";
        
        foreach ($tables as $table) {
            $result = $this->db->query("SELECT * FROM $table");
            $numFields = $result->columnCount();
            
            $output .= "DROP TABLE IF EXISTS `$table`;\n";
            
            $createTableResult = $this->db->query("SHOW CREATE TABLE $table");
            $row2 = $createTableResult->fetch(PDO::FETCH_NUM);
            $output .= "\n" . $row2[1] . ";\n\n";
            
            while ($row = $result->fetch(PDO::FETCH_NUM)) {
                $output .= "INSERT INTO `$table` VALUES(";
                for ($j = 0; $j < $numFields; $j++) {
                    $row[$j] = addslashes($row[$j]);
                    $row[$j] = str_replace("\n", "\\n", $row[$j]);
                    if (isset($row[$j])) {
                        $output .= '"' . $row[$j] . '"';
                    } else {
                        $output .= '""';
                    }
                    if ($j < ($numFields - 1)) {
                        $output .= ',';
                    }
                }
                $output .= ");\n";
            }
            $output .= "\n\n";
        }
        
        file_put_contents($filepath, $output);
    }
    
    private function logBackup($filename, $size, $type) {
        $stmt = $this->db->prepare("
            INSERT INTO backup_history (filename, size, type, status, created_at)
            VALUES (:filename, :size, :type, 'completed', NOW())
        ");
        
        $stmt->execute([
            ':filename' => $filename,
            ':size' => $size,
            ':type' => $type
        ]);
    }
    
    public function restoreBackup($backupId) {
        try {
            // التحقق من وجود النسخة الاحتياطية
            $stmt = $this->db->prepare("
                SELECT filename FROM backup_history 
                WHERE id = :id AND status = 'completed'
            ");
            $stmt->execute([':id' => $backupId]);
            $backup = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$backup) {
                throw new Exception("النسخة الاحتياطية غير موجودة");
            }
            
            $filepath = $this->backupDir . $backup['filename'];
            if (!file_exists($filepath)) {
                throw new Exception("ملف النسخة الاحتياطية غير موجود");
            }
            
            // تنفيذ عملية الاستعادة
            $sql = file_get_contents($filepath);
            $this->db->exec($sql);
            
            return true;
        } catch (Exception $e) {
            error_log("Restore Error: " . $e->getMessage());
            return false;
        }
    }
    
    public function cleanOldBackups($days) {
        try {
            $stmt = $this->db->prepare("
                SELECT filename FROM backup_history 
                WHERE created_at < DATE_SUB(NOW(), INTERVAL :days DAY)
            ");
            $stmt->execute([':days' => $days]);
            
            while ($backup = $stmt->fetch(PDO::FETCH_ASSOC)) {
                $filepath = $this->backupDir . $backup['filename'];
                if (file_exists($filepath)) {
                    unlink($filepath);
                }
            }
            
            $this->db->prepare("
                DELETE FROM backup_history 
                WHERE created_at < DATE_SUB(NOW(), INTERVAL :days DAY)
            ")->execute([':days' => $days]);
            
            return true;
        } catch (Exception $e) {
            error_log("Cleanup Error: " . $e->getMessage());
            return false;
        }
    }
}