<?php
header('Content-Type: application/json');
require_once '../../config.php';

$data = json_decode(file_get_contents('php://input'), true);
$response = [];

try {
    switch($data['type']) {
        case 'financial':
            $response = generateFinancialReport($conn, $data['filters']);
            break;
        case 'projects':
            $response = generateProjectsReport($conn, $data['filters']);
            break;
        case 'workers':
            $response = generateWorkersReport($conn, $data['filters']);
            break;
    }
    
    echo json_encode($response);
} catch(Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => $e->getMessage()]);
}

function generateFinancialReport($conn, $filters) {
    // تحديد نطاق التاريخ
    $dateRange = getDateRange($filters['period'], $filters['startDate'] ?? null, $filters['endDate'] ?? null);
    
    // الاستعلام عن البيانات المالية
    $query = "
        SELECT 
            SUM(CASE WHEN type = 'revenue' THEN amount ELSE 0 END) as total_revenues,
            SUM(CASE WHEN type = 'expense' THEN amount ELSE 0 END) as total_expenses,
            SUM(CASE WHEN type = 'expense' AND payment_status = 'pending' THEN amount ELSE 0 END) as pending_expenses
        FROM (
            SELECT 'revenue' as type, amount, NULL as payment_status, transaction_date as date
            FROM revenues
            WHERE transaction_date BETWEEN :start_date AND :end_date
            UNION ALL
            SELECT 'expense' as type, amount, payment_status, expense_date as date
            FROM expenses
            WHERE expense_date BETWEEN :start_date AND :end_date
        ) as combined_data
    ";
    
    if (!empty($filters['projectId'])) {
        $query .= " WHERE project_id = :project_id";
    }
    
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':start_date', $dateRange['start']);
    $stmt->bindParam(':end_date', $dateRange['end']);
    
    if (!empty($filters['projectId'])) {
        $stmt->bindParam(':project_id', $filters['projectId']);
    }
    
    $stmt->execute();
    $summary = $stmt->fetch(PDO::FETCH_ASSOC);
    
    // الحصول على البيانات الشهرية للرسوم البيانية
    $chartData = getMonthlyFinancialData($conn, $dateRange, $filters['projectId'] ?? null);
    
    return [
        'summary' => [
            'totalRevenues' => $summary['total_revenues'] ?? 0,
            'totalExpenses' => $summary['total_expenses'] ?? 0,
            'netProfit' => ($summary['total_revenues'] ?? 0) - ($summary['total_expenses'] ?? 0),
            'pendingExpenses' => $summary['pending_expenses'] ?? 0
        ],
        'charts' => $chartData,
        'details' => [
            'revenues' => getRevenuesDetails($conn, $dateRange, $filters['projectId'] ?? null),
            'expenses' => getExpensesDetails($conn, $dateRange, $filters['projectId'] ?? null)
        ]
    ];
}

function getDateRange($period, $startDate = null, $endDate = null) {
    $today = date('Y-m-d');
    
    switch($period) {
        case 'today':
            return ['start' => $today, 'end' => $today];
        case 'week':
            return [
                'start' => date('Y-m-d', strtotime('monday this week')),
                'end' => date('Y-m-d', strtotime('sunday this week'))
            ];
        case 'month':
            return [
                'start' => date('Y-m-01'),
                'end' => date('Y-m-t')
            ];
        case 'year':
            return [
                'start' => date('Y-01-01'),
                'end' => date('Y-12-31')
            ];
        case 'custom':
            return [
                'start' => $startDate,
                'end' => $endDate
            ];
        default:
            return [
                'start' => date('Y-m-01'),
                'end' => date('Y-m-t')
            ];
    }
}

function getMonthlyFinancialData($conn, $dateRange, $projectId = null) {
    // استعلام للحصول على البيانات الشهرية
    $query = "
        SELECT 
            DATE_FORMAT(date, '%Y-%m') as month,
            SUM(CASE WHEN type = 'revenue' THEN amount ELSE 0 END) as revenue,
            SUM(CASE WHEN type = 'expense' THEN amount ELSE 0 END) as expense
        FROM (
            SELECT 'revenue' as type, amount, transaction_date as date
            FROM revenues
            WHERE transaction_date BETWEEN :start_date AND :end_date
            UNION ALL
            SELECT 'expense' as type, amount, expense_date as date
            FROM expenses
            WHERE expense_date BETWEEN :start_date AND :end_date
        ) as combined_data
    ";
    
    if ($projectId) {
        $query .= " WHERE project_id = :project_id";
    }
    
    $query .= " GROUP BY DATE_FORMAT(date, '%Y-%m')
                ORDER BY month";
    
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':start_date', $dateRange['start']);
    $stmt->bindParam(':end_date', $dateRange['end']);
    
    if ($projectId) {
        $stmt->bindParam(':project_id', $projectId);
    }
    
    $stmt->execute();
    $monthlyData = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // تنظيم البيانات للرسوم البيانية
    $months = [];
    $revenues = [];
    $expenses = [];
    $profits = [];
    
    foreach ($monthlyData as $data) {
        $months[] = date('M Y', strtotime($data['month'] . '-01'));
        $revenues[] = $data['revenue'];
        $expenses[] = $data['expense'];
        $profits[] = $data['revenue'] - $data['expense'];
    }
    
    return [
        'months' => $months,
        'revenues' => $revenues,
        'expenses' => $expenses,
        'profits' => $profits
    ];
}