document.addEventListener('DOMContentLoaded', function() {
  loadBackupStatus();
  loadBackupSettings();
  loadBackupHistory();

  // إعداد مستمعي الأحداث
  setupEventListeners();
});

function setupEventListeners() {
  document.getElementById('createBackup').addEventListener('click', createBackup);
  document.getElementById('restoreBackup').addEventListener('click', showRestoreModal);
  document.getElementById('downloadBackup').addEventListener('click', downloadLatestBackup);
  document.getElementById('backupSettingsForm').addEventListener('submit', saveBackupSettings);
  document.getElementById('restoreForm').addEventListener('submit', restoreBackup);
}

async function loadBackupStatus() {
  try {
    const response = await fetch('api/backup/status.php');
    const data = await response.json();

    document.getElementById('lastBackupDate').textContent = data.lastBackup || 'لا يوجد';
    document.getElementById('databaseSize').textContent = data.databaseSize;
    document.getElementById('autoBackupStatus').textContent = data.autoBackupEnabled ? 'مفعل' : 'غير مفعل';
  } catch (error) {
    showNotification('فشل في تحميل حالة النسخ الاحتياطي', 'error');
  }
}

async function loadBackupSettings() {
  try {
    const response = await fetch('api/backup/settings.php');
    const settings = await response.json();

    document.getElementById('autoBackupEnabled').checked = settings.enabled;
    document.getElementById('backupFrequency').value = settings.frequency;
    document.getElementById('backupTime').value = settings.time;
    document.getElementById('retentionDays').value = settings.retentionDays;
  } catch (error) {
    showNotification('فشل في تحميل إعدادات النسخ الاحتياطي', 'error');
  }
}

async function loadBackupHistory() {
  try {
    const response = await fetch('api/backup/history.php');
    const history = await response.json();

    const tbody = document.getElementById('backupHistoryTable');
    tbody.innerHTML = '';

    history.forEach(backup => {
      const tr = document.createElement('tr');
      tr.innerHTML = `
                <td>${formatDate(backup.created_at)}</td>
                <td>${backup.type === 'auto' ? 'تلقائي' : 'يدوي'}</td>
                <td>${formatSize(backup.size)}</td>
                <td>
                    <span class="status-badge ${backup.status}">
                        ${getStatusText(backup.status)}
                    </span>
                </td>
                <td>
                    <button class="btn" onclick="downloadBackup('${backup.id}')">تحميل</button>
                    <button class="btn" onclick="deleteBackup('${backup.id}')">حذف</button>
                </td>
            `;
      tbody.appendChild(tr);
    });
  } catch (error) {
    showNotification('فشل في تحميل سجل النسخ الاحتياطي', 'error');
  }
}

async function createBackup() {
  try {
    const response = await fetch('api/backup/create.php', {
      method: 'POST'
    });

    if (response.ok) {
      showNotification('تم إنشاء النسخة الاحتياطية بنجاح');
      loadBackupStatus();
      loadBackupHistory();
    } else {
      throw new Error('فشل في إنشاء النسخة الاحتياطية');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

async function saveBackupSettings(e) {
  e.preventDefault();

  const formData = new FormData(e.target);
  const settings = {
    enabled: formData.get('autoBackupEnabled') === 'on',
    frequency: formData.get('backupFrequency'),
    time: formData.get('backupTime'),
    retentionDays: formData.get('retentionDays')
  };

  try {
    const response = await fetch('api/backup/settings.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(settings)
    });

    if (response.ok) {
      showNotification('تم حفظ الإعدادات بنجاح');
      loadBackupStatus();
    } else {
      throw new Error('فشل في حفظ الإعدادات');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

async function restoreBackup(e) {
  e.preventDefault();

  if (!confirm('هل أنت متأكد من استعادة النسخة الاحتياطية؟ سيتم استبدال جميع البيانات الحالية.')) {
    return;
  }

  const formData = new FormData(e.target);

  try {
    const response = await fetch('api/backup/restore.php', {
      method: 'POST',
      body: formData
    });

    if (response.ok) {
      showNotification('تم استعادة النسخة الاحتياطية بنجاح');
      window.location.reload();
    } else {
      throw new Error('فشل في استعادة النسخة الاحتياطية');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

// وظائف مساعدة
function formatDate(dateString) {
  return new Date(dateString).toLocaleString('ar-SA');
}

function formatSize(bytes) {
  const sizes = ['بايت', 'كيلوبايت', 'ميجابايت', 'جيجابايت'];
  if (bytes === 0) return '0 بايت';
  const i = parseInt(Math.floor(Math.log(bytes) / Math.log(1024)));
  return Math.round(bytes / Math.pow(1024, i), 2) + ' ' + sizes[i];
}

function getStatusText(status) {
  const statusMap = {
    'completed': 'مكتمل',
    'failed': 'فشل',
    'in_progress': 'جاري التنفيذ'
  };
  return statusMap[status] || status;
}

function showNotification(message, type = 'success') {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;
  notification.textContent = message;

  document.body.appendChild(notification);

  setTimeout(() => {
    notification.remove();
  }, 3000);
}