let expenses = [];
let revenues = [];
let projects = [];

document.addEventListener('DOMContentLoaded', function() {
    // تحميل البيانات الأولية
    loadProjects();
    loadExpenses();
    loadRevenues();
    
    // إعداد مستمعي الأحداث
    setupEventListeners();
});

function setupEventListeners() {
    // التبويبات
    document.querySelectorAll('.tab-btn').forEach(btn => {
        btn.addEventListener('click', () => switchTab(btn.dataset.tab));
    });
    
    // نماذج
    document.getElementById('addExpenseForm').addEventListener('submit', handleAddExpense);
    document.getElementById('addRevenueForm').addEventListener('submit', handleAddRevenue);
    
    // الفلاتر
    const filterInputs = [
        'expenseStartDate', 'expenseEndDate', 'expenseProjectFilter', 'expenseTypeFilter',
        'revenueStartDate', 'revenueEndDate', 'revenueProjectFilter', 'paymentMethodFilter'
    ];
    
    filterInputs.forEach(id => {
        document.getElementById(id).addEventListener('change', () => {
            if (id.startsWith('expense')) {
                filterExpenses();
            } else {
                filterRevenues();
            }
        });
    });
}

// تحميل البيانات
async function loadProjects() {
    try {
        const response = await fetch('api/projects/get_all.php');
        projects = await response.json();
        updateProjectsDropdowns();
    } catch (error) {
        showNotification('فشل في تحميل المشاريع', 'error');
    }
}

async function loadExpenses() {
    try {
        const response = await fetch('api/finances/get_expenses.php');
        expenses = await response.json();
        renderExpenses(expenses);
    } catch (error) {
        showNotification('فشل في تحميل المصروفات', 'error');
    }
}

async function loadRevenues() {
    try {
        const response = await fetch('api/finances/get_revenues.php');
        revenues = await response.json();
        renderRevenues(revenues);
    } catch (error) {
        showNotification('فشل في تحميل الإيرادات', 'error');
    }
}

// عرض البيانات
function renderExpenses(expensesToShow) {
    const tbody = document.getElementById('expensesTableBody');
    tbody.innerHTML = '';
    let total = 0;
    
    expensesToShow.forEach(expense => {
        total += parseFloat(expense.amount);
        const tr = document.createElement('tr');
        tr.innerHTML = `
            <td>${formatDate(expense.expense_date)}</td>
            <td>${getProjectName(expense.project_id)}</td>
            <td>${expense.description || '-'}</td>
            <td>${formatCurrency(expense.amount)}</td>
            <td>${expense.expense_type === 'cash' ? 'نقدي' : 'آجل'}</td>
            <td>
                <span class="status-badge status-${expense.payment_status}">
                    ${expense.payment_status === 'paid' ? 'مدفوع' : 'معلق'}
                </span>
            </td>
            <td class="actions-cell">
                <button class="btn edit-btn" onclick="editExpense(${expense.id})">تعديل</button>
                <button class="btn delete-btn" onclick="deleteExpense(${expense.id})">حذف</button>
                <button class="btn print-btn" onclick="printExpense(${expense.id})">طباعة</button>
            </td>
        `;
        tbody.appendChild(tr);
    });
    
    document.getElementById('totalExpenses').textContent = formatCurrency(total);
}

function renderRevenues(revenuesToShow) {
    const tbody = document.getElementById('revenuesTableBody');
    tbody.innerHTML = '';
    let total = 0;
    
    revenuesToShow.forEach(revenue => {
        total += parseFloat(revenue.amount);
        const tr = document.createElement('tr');
        tr.innerHTML = `
            <td>${formatDate(revenue.revenue_date)}</td>
            <td>${getProjectName(revenue.project_id)}</td>
            <td>${revenue.description || '-'}</td>
            <td>${formatCurrency(revenue.amount)}</td>
            <td>${getPaymentMethodArabic(revenue.payment_method)}</td>
            <td class="actions-cell">
                <button class="btn edit-btn" onclick="editRevenue(${revenue.id})">تعديل</button>
                <button class="btn delete-btn" onclick="deleteRevenue(${revenue.id})">حذف</button>
                <button class="btn print-btn" onclick="printRevenue(${revenue.id})">طباعة</button>
            </td>
        `;
        tbody.appendChild(tr);
    });
    
    document.getElementById('totalRevenues').textContent = formatCurrency(total);
}

// إضافة مصروف جديد
async function handleAddExpense(e) {
    e.preventDefault();
    
    const formData = new FormData(e.target);
    const expenseData = {
        project_id: formData.get('project_id'),
        expense_date: formData.get('expense_date'),
        amount: formData.get('amount'),
        expense_type: formData.get('expense_type'),
        description: formData.get('description'),
        payment_status: formData.get('expense_type') === 'cash' ? 'paid' : 'pending'
    };
    
    try {
        const response = await fetch('api/finances/add_expense.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(expenseData)
        });
        
        if (response.ok) {
            closeModal('addExpenseModal');
            loadExpenses();
            showNotification('تم إضافة المصروف بنجاح');
            e.target.reset();
        } else {
            throw new Error('فشل في إضافة المصروف');
        }
    } catch (error) {
        showNotification(error.message, 'error');
    }
}

// إضافة إيراد جديد
async function handleAddRevenue(e) {
    e.preventDefault();
    
    const formData = new FormData(e.target);
    const revenueData = {
        project_id: formData.get('project_id'),
        revenue_date: formData.get('revenue_date'),
        amount: formData.get('amount'),
        payment_method: formData.get('payment_method'),
        description: formData.get('description')
    };
    
    try {
        const response = await fetch('api/finances/add_revenue.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(revenueData)
        });
        
        if (response.ok) {
            closeModal('addRevenueModal');
            loadRevenues();
            showNotification('تم إضافة الإيراد بنجاح');
            e.target.reset();
        } else {
            throw new Error('فشل في إضافة الإيراد');
        }
    } catch (error) {
        showNotification(error.message, 'error');
    }
}

// وظائف مساعدة
function formatDate(dateString) {
    return new Date(dateString).toLocaleDateString('ar-SA');
}

function formatCurrency(amount) {
    return `${parseFloat(amount).toLocaleString('ar-SA')} ريال`;
}

function getProjectName(projectId) {
    const project = projects.find(p => p.id === projectId);
    return project ? project.project_name : '-';
}

function getPaymentMethodArabic(method) {
    const methods = {
        'cash': 'نقدي',
        'bank': 'بنك',
        'transfer': 'حوالة'
    };
    return methods[method] || method;
}

// طباعة المستندات
function printExpense(expenseId) {
    const expense = expenses.find(e => e.id === expenseId);
    if (!expense) return;
    
    const printWindow = window.open('', '', 'width=800,height=600');
    printWindow.document.write(`
        <html dir="rtl">
        <head>
            <title>سند صرف</title>
            <style>
                body { font-family: Arial, sans-serif; }
                .header { text-align: center; margin-bottom: 20px; }
                .content { margin: 20px; }
                .footer { margin-top: 40px; }
                .signature { margin-top: 60px; }
            </style>
        </head>
        <body>
            <div class="header">
                <h2>سند صرف</h2>
                <p>رقم: ${expense.id}</p>
            </div>
            <div class="content">
                <p>التاريخ: ${formatDate(expense.expense_date)}</p>
                <p>المشروع: ${getProjectName(expense.project_id)}</p>
                <p>المبلغ: ${formatCurrency(expense.amount)}</p>
                <p>نوع المصروف: ${expense.expense_type === 'cash' ? 'نقدي' : 'آجل'}</p>
                <p>الوصف: ${expense.description || '-'}</p>
            </div>
            <div class="signature">
                <p>التوقيع: ________________</p>
            </div>
        </body>
        </html>
    `);
    printWindow.document.close();
    printWindow.print();
}

// تحديث القوائم المنسدلة للمشاريع
function updateProjectsDropdowns() {
    const dropdowns = [
        'expenseProjectFilter',
        'revenueProjectFilter',
        'addExpenseForm',
        'addRevenueForm'
    ].map(id => document.querySelector(`#${id} select[name="project_id"]`));
    
    dropdowns.forEach(dropdown => {
        if (!dropdown) return;
        
        dropdown.innerHTML = '<option value="">اختر المشروع</option>';
        projects.forEach(project => {
            const option = document.createElement('option');
            option.value = project.id;
            option.textContent = project.project_name;
            dropdown.appendChild(option);
        });
    });
}

// التبديل بين التبويبات
function switchTab(tabName) {
    document.querySelectorAll('.tab-btn').forEach(btn => {
        btn.classList.toggle('active', btn.dataset.tab === tabName);
    });
    
    document.querySelectorAll('.tab-content').forEach(content => {
        content.classList.toggle('active', content.id === `${tabName}-content`);
    });
}

// إظهار/إخفاء النوافذ المنبثقة
function showModal(modalId) {
    document.getElementById(modalId).style.display = 'block';
}

function closeModal(modalId) {
    document.getElementById(modalId).style.display = 'none';
}

// إظهار الإشعارات
function showNotification(message, type = 'success') {
    const notification = document.createElement('div');
    notification.className = `notification ${type}`;
    notification.textContent = message;
    
    document.body.appendChild(notification);
    
    setTimeout(() => {
        notification.remove();
    }, 3000);
}