let currentPage = 1;
let isLoading = false;
let hasMore = true;

document.addEventListener('DOMContentLoaded', function() {
  setupEventListeners();
  loadNotifications();
  initializeWebSocket();
});

function setupEventListeners() {
  document.getElementById('markAllRead').addEventListener('click', markAllAsRead);
  document.getElementById('notificationSettings').addEventListener('click', showSettingsModal);
  document.getElementById('loadMore').addEventListener('click', loadMoreNotifications);
  document.getElementById('notificationSettingsForm').addEventListener('submit', saveNotificationSettings);

  // فلاتر الإشعارات
  document.getElementById('typeFilter').addEventListener('change', filterNotifications);
  document.getElementById('statusFilter').addEventListener('change', filterNotifications);
}

function initializeWebSocket() {
  const ws = new WebSocket('ws://your-domain/notifications-ws');

  ws.onmessage = function(event) {
    const notification = JSON.parse(event.data);
    addNewNotification(notification);
    showNotificationPopup(notification);
  };

  ws.onerror = function(error) {
    console.error('WebSocket Error:', error);
  };

  ws.onclose = function() {
    setTimeout(initializeWebSocket, 5000); // إعادة الاتصال بعد 5 ثواني
  };
}

async function loadNotifications(reset = false) {
  if (isLoading || (!hasMore && !reset)) return;

  isLoading = true;
  if (reset) {
    currentPage = 1;
    document.getElementById('notificationsList').innerHTML = '';
    hasMore = true;
  }

  const filters = {
    type: document.getElementById('typeFilter').value,
    status: document.getElementById('statusFilter').value,
    page: currentPage
  };

  try {
    const response = await fetch(`api/notifications/get.php?${new URLSearchParams(filters)}`);
    const data = await response.json();

    renderNotifications(data.notifications);
    hasMore = data.hasMore;
    currentPage++;

    document.getElementById('loadMore').style.display = hasMore ? 'block' : 'none';
  } catch (error) {
    showNotification('فشل في تحميل الإشعارات', 'error');
  } finally {
    isLoading = false;
  }
}

function renderNotifications(notifications) {
  const container = document.getElementById('notificationsList');

  notifications.forEach(notification => {
    const notificationElement = createNotificationElement(notification);
    container.appendChild(notificationElement);
  });
}

function createNotificationElement(notification) {
  const div = document.createElement('div');
  div.className = `notification-item ${notification.read ? '' : 'unread'}`;
  div.innerHTML = `
        <div class="notification-icon ${notification.type}">
            ${getNotificationIcon(notification.type)}
        </div>
        <div class="notification-content">
            <div class="notification-header">
                <span class="notification-title">${notification.title}</span>
                <span class="notification-time">${formatTime(notification.created_at)}</span>
            </div>
            <div class="notification-message">${notification.message}</div>
            <div class="notification-actions">
                ${!notification.read ? 
                    `<button class="mark-read" onclick="markAsRead('${notification.id}')">
                        تعليم كمقروء
                    </button>` : ''
                }
                ${notification.link ? 
                    `<button class="view-details" onclick="window.location.href='${notification.link}'">
                        عرض التفاصيل
                    </button>` : ''
                }
            </div>
        </div>
    `;
  return div;
}

function getNotificationIcon(type) {
  const icons = {
    project: '<i class="fas fa-project-diagram"></i>',
    financial: '<i class="fas fa-money-bill-wave"></i>',
    worker: '<i class="fas fa-user-hard-hat"></i>',
    system: '<i class="fas fa-cog"></i>'
  };
  return icons[type] || '<i class="fas fa-bell"></i>';
}

async function markAsRead(notificationId) {
  try {
    const response = await fetch('api/notifications/mark_read.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ id: notificationId })
    });

    if (response.ok) {
      const notification = document.querySelector(`[data-notification-id="${notificationId}"]`);
      if (notification) {
        notification.classList.remove('unread');
        notification.querySelector('.mark-read')?.remove();
      }
      updateUnreadCount();
    }
  } catch (error) {
    showNotification('فشل في تعليم الإشعار كمقروء', 'error');
  }
}

async function markAllAsRead() {
  try {
    const response = await fetch('api/notifications/mark_all_read.php', {
      method: 'POST'
    });

    if (response.ok) {
      document.querySelectorAll('.notification-item.unread').forEach(item => {
        item.classList.remove('unread');
        item.querySelector('.mark-read')?.remove();
      });
      updateUnreadCount();
      showNotification('تم تعليم جميع الإشعارات كمقروءة');
    }
  } catch (error) {
    showNotification('فشل في تعليم جميع الإشعارات كمقروءة', 'error');
  }
}

async function saveNotificationSettings(e) {
  e.preventDefault();

  const formData = new FormData(e.target);
  const settings = {
    project_updates: formData.get('project_updates') === 'on',
    project_completion: formData.get('project_completion') === 'on',
    payment_received: formData.get('payment_received') === 'on',
    payment_due: formData.get('payment_due') === 'on',
    worker_attendance: formData.get('worker_attendance') === 'on',
    worker_payment: formData.get('worker_payment') === 'on',
    web_notifications: formData.get('web_notifications') === 'on',
    email_notifications: formData.get('email_notifications') === 'on'
  };

  try {
    const response = await fetch('api/notifications/settings.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(settings)
    });

    if (response.ok) {
      closeSettingsModal();
      showNotification('تم حفظ إعدادات الإشعارات بنجاح');
    } else {
      throw new Error('فشل في حفظ الإعدادات');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

function showNotificationPopup(notification) {
  if (!("Notification" in window)) return;

  if (Notification.permission === "granted") {
    new Notification(notification.title, {
      body: notification.message,
      icon: '/path/to/notification-icon.png'
    });
  } else if (Notification.permission !== "denied") {
    Notification.requestPermission().then(permission => {
      if (permission === "granted") {
        showNotificationPopup(notification);
      }
    });
  }
}

function formatTime(timestamp) {
  const date = new Date(timestamp);
  const now = new Date();
  const diff = now - date;

  if (diff < 60000) { // أقل من دقيقة
    return 'الآن';
  } else if (diff < 3600000) { // أقل من ساعة
    const minutes = Math.floor(diff / 60000);
    return `منذ ${minutes} دقيقة`;
  } else if (diff < 86400000) { // أقل من يوم
    const hours = Math.floor(diff / 3600000);
    return `منذ ${hours} ساعة`;
  } else {
    return date.toLocaleDateString('ar-SA');
  }
}

function updateUnreadCount() {
  // تحديث عداد الإشعارات غير المقروءة في الشريط الجانبي
  const unreadCount = document.querySelectorAll('.notification-item.unread').length;
  document.getElementById('unreadNotificationsCount').textContent = unreadCount;
}

function showSettingsModal() {
  document.getElementById('settingsModal').style.display = 'block';
}

function closeSettingsModal() {
  document.getElementById('settingsModal').style.display = 'none';
}

function filterNotifications() {
  loadNotifications(true);
}

function loadMoreNotifications() {
  loadNotifications();
}

function showNotification(message, type = 'success') {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;
  notification.textContent = message;

  document.body.appendChild(notification);

  setTimeout(() => {
    notification.remove();
  }, 3000);
}