let currentReportType = 'financial';
let reportData = {};

document.addEventListener('DOMContentLoaded', function() {
  setupEventListeners();
  loadInitialData();
});

function setupEventListeners() {
  // مستمعي أحداث أزرار التقارير
  document.querySelectorAll('.report-btn').forEach(btn => {
    btn.addEventListener('click', () => switchReportType(btn.dataset.report));
  });

  // مستمع حدث تغيير الفترة
  document.getElementById('periodFilter').addEventListener('change', handlePeriodChange);

  // أزرار إنشاء وطباعة وتصدير التقرير
  document.getElementById('generateReport').addEventListener('click', generateReport);
  document.getElementById('printReport').addEventListener('click', printReport);
  document.getElementById('exportExcel').addEventListener('click', exportToExcel);
}

async function loadInitialData() {
  try {
    // تحميل المشاريع للفلتر
    const projectsResponse = await fetch('api/projects/get_all.php');
    const projects = await projectsResponse.json();
    updateProjectsDropdown(projects);

    // تحميل البيانات الأولية للتقرير الحالي
    generateReport();
  } catch (error) {
    showNotification('فشل في تحميل البيانات', 'error');
  }
}

function switchReportType(type) {
  currentReportType = type;

  // تحديث الأزرار النشطة
  document.querySelectorAll('.report-btn').forEach(btn => {
    btn.classList.toggle('active', btn.dataset.report === type);
  });

  // تحديث القسم النشط
  document.querySelectorAll('.report-section').forEach(section => {
    section.classList.toggle('active', section.id === `${type}-report`);
  });

  // إعادة توليد التقرير
  generateReport();
}

async function generateReport() {
  const filters = getReportFilters();

  try {
    const response = await fetch('api/reports/generate.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        type: currentReportType,
        filters: filters
      })
    });

    reportData = await response.json();
    updateReportView();
  } catch (error) {
    showNotification('فشل في إنشاء التقرير', 'error');
  }
}

function updateReportView() {
  switch (currentReportType) {
    case 'financial':
      updateFinancialReport();
      break;
    case 'projects':
      updateProjectsReport();
      break;
    case 'workers':
      updateWorkersReport();
      break;
  }
}

function updateFinancialReport() {
  // تحديث البطاقات الملخصة
  document.getElementById('totalRevenues').textContent = formatCurrency(reportData.summary.totalRevenues);
  document.getElementById('totalExpenses').textContent = formatCurrency(reportData.summary.totalExpenses);
  document.getElementById('netProfit').textContent = formatCurrency(reportData.summary.netProfit);
  document.getElementById('pendingExpenses').textContent = formatCurrency(reportData.summary.pendingExpenses);

  // تحديث الرسوم البيانية
  updateRevenueExpenseChart();
  updateProfitTrendChart();

  // تحديث الجداول
  updateRevenuesTable();
  updateExpensesTable();
}

function updateRevenueExpenseChart() {
  const ctx = document.getElementById('revenueExpenseChart').getContext('2d');
  new Chart(ctx, {
    type: 'bar',
    data: {
      labels: reportData.charts.months,
      datasets: [{
        label: 'الإيرادات',
        data: reportData.charts.revenues,
        backgroundColor: 'rgba(75, 192, 192, 0.2)',
        borderColor: 'rgba(75, 192, 192, 1)',
        borderWidth: 1
            }, {
        label: 'المصروفات',
        data: reportData.charts.expenses,
        backgroundColor: 'rgba(255, 99, 132, 0.2)',
        borderColor: 'rgba(255, 99, 132, 1)',
        borderWidth: 1
            }]
    },
    options: {
      responsive: true,
      plugins: {
        title: {
          display: true,
          text: 'مقارنة الإيرادات والمصروفات'
        }
      }
    }
  });
}

function updateProfitTrendChart() {
  const ctx = document.getElementById('profitTrendChart').getContext('2d');
  new Chart(ctx, {
    type: 'line',
    data: {
      labels: reportData.charts.months,
      datasets: [{
        label: 'صافي الربح',
        data: reportData.charts.profits,
        borderColor: 'rgba(54, 162, 235, 1)',
        tension: 0.1
            }]
    },
    options: {
      responsive: true,
      plugins: {
        title: {
          display: true,
          text: 'اتجاه الربحية'
        }
      }
    }
  });
}

function printReport() {
  window.print();
}

async function exportToExcel() {
  try {
    const response = await fetch('api/reports/export_excel.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        type: currentReportType,
        data: reportData
      })
    });

    const blob = await response.blob();
    const url = window.URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = `${currentReportType}_report.xlsx`;
    document.body.appendChild(a);
    a.click();
    window.URL.revokeObjectURL(url);
    a.remove();
  } catch (error) {
    showNotification('فشل في تصدير التقرير', 'error');
  }
}

function getReportFilters() {
  const periodFilter = document.getElementById('periodFilter').value;
  const filters = {
    period: periodFilter,
    projectId: document.getElementById('projectFilter').value
  };

  if (periodFilter === 'custom') {
    filters.startDate = document.getElementById('startDate').value;
    filters.endDate = document.getElementById('endDate').value;
  }

  return filters;
}

function handlePeriodChange(e) {
  const customDateRange = document.querySelector('.custom-date-range');
  customDateRange.style.display = e.target.value === 'custom' ? 'flex' : 'none';
}

function formatCurrency(amount) {
  return `${parseFloat(amount).toLocaleString('ar-SA')} ريال`;
}

function showNotification(message, type = 'success') {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;
  notification.textContent = message;

  document.body.appendChild(notification);

  setTimeout(() => {
    notification.remove();
  }, 3000);
}