let workers = [];
let projects = [];

document.addEventListener('DOMContentLoaded', function() {
  loadWorkers();
  loadProjects();

  // إضافة مستمعي الأحداث
  document.getElementById('searchWorker').addEventListener('input', filterWorkers);
  document.getElementById('statusFilter').addEventListener('change', filterWorkers);
  document.getElementById('addWorkerForm').addEventListener('submit', handleAddWorker);
  document.getElementById('dailyRecordForm').addEventListener('submit', handleDailyRecord);
});

// تحميل بيانات العمال
async function loadWorkers() {
  try {
    const response = await fetch('api/workers/get_all.php');
    workers = await response.json();
    renderWorkers(workers);
  } catch (error) {
    showNotification('فشل في تحميل بيانات العمال', 'error');
  }
}

// تحميل المشاريع النشطة
async function loadProjects() {
  try {
    const response = await fetch('api/projects/get_active.php');
    projects = await response.json();
    updateProjectsDropdown();
  } catch (error) {
    showNotification('فشل في تحميل بيانات المشاريع', 'error');
  }
}

// عرض العمال في الجدول
function renderWorkers(workersToShow) {
  const tbody = document.getElementById('workersTableBody');
  tbody.innerHTML = '';

  workersToShow.forEach(worker => {
    const tr = document.createElement('tr');
    tr.innerHTML = `
            <td>${worker.worker_code}</td>
            <td>${worker.full_name}</td>
            <td>${worker.phone || '-'}</td>
            <td>${worker.daily_wage} ريال</td>
            <td>
                <span class="status-badge status-${worker.status}">
                    ${worker.status === 'active' ? 'نشط' : 'غير نشط'}
                </span>
            </td>
            <td>${worker.dues || 0} ريال</td>
            <td class="actions-cell">
                <button class="btn attendance-btn" onclick="showDailyRecordModal(${worker.id})">
                    تسجيل دوام
                </button>
                <button class="btn edit-btn" onclick="editWorker(${worker.id})">
                    تعديل
                </button>
                <button class="btn delete-btn" onclick="deleteWorker(${worker.id})">
                    حذف
                </button>
            </td>
        `;
    tbody.appendChild(tr);
  });
}

// فلترة العمال
function filterWorkers() {
  const searchText = document.getElementById('searchWorker').value.toLowerCase();
  const statusFilter = document.getElementById('statusFilter').value;

  let filtered = workers;

  if (searchText) {
    filtered = filtered.filter(worker =>
      worker.full_name.toLowerCase().includes(searchText) ||
      worker.worker_code.toLowerCase().includes(searchText)
    );
  }

  if (statusFilter) {
    filtered = filtered.filter(worker => worker.status === statusFilter);
  }

  renderWorkers(filtered);
}

// إضافة عامل جديد
async function handleAddWorker(e) {
  e.preventDefault();

  const formData = new FormData(e.target);
  const workerData = {
    worker_code: formData.get('workerCode'),
    full_name: formData.get('fullName'),
    phone: formData.get('phone'),
    daily_wage: formData.get('dailyWage'),
    status: 'active'
  };

  try {
    const response = await fetch('api/workers/add.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(workerData)
    });

    if (response.ok) {
      closeModal('addWorkerModal');
      loadWorkers();
      showNotification('تم إضافة العامل بنجاح');
      e.target.reset();
    } else {
      throw new Error('فشل في إضافة العامل');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

// تسجيل دوام يومي
async function handleDailyRecord(e) {
  e.preventDefault();

  const formData = new FormData(e.target);
  const recordData = {
    worker_id: formData.get('workerId'),
    project_id: formData.get('projectId'),
    work_date: formData.get('workDate'),
    hours_worked: formData.get('hoursWorked')
  };

  try {
    const response = await fetch('api/workers/add_daily_record.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(recordData)
    });

    if (response.ok) {
      closeModal('dailyRecordModal');
      loadWorkers(); // تحديث بيانات العمال
      showNotification('تم تسجيل الدوام بنجاح');
      e.target.reset();
    } else {
      throw new Error('فشل في تسجيل الدوام');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

// حذف عامل
async function deleteWorker(workerId) {
  if (confirm('هل أنت متأكد من حذف هذا العامل؟')) {
    try {
      const response = await fetch(`api/workers/delete.php?id=${workerId}`, {
        method: 'DELETE'
      });

      if (response.ok) {
        loadWorkers();
        showNotification('تم حذف العامل بنجاح');
      } else {
        throw new Error('فشل في حذف العامل');
      }
    } catch (error) {
      showNotification(error.message, 'error');
    }
  }
}

// تحديث قائمة المشاريع في نموذج تسجيل الدوام
function updateProjectsDropdown() {
  const select = document.getElementById('projectId');
  select.innerHTML = '<option value="">اختر المشروع</option>';

  projects.forEach(project => {
    const option = document.createElement('option');
    option.value = project.id;
    option.textContent = project.project_name;
    select.appendChild(option);
  });
}

// إظهار نموذج تسجيل الدوام
function showDailyRecordModal(workerId) {
  document.getElementById('workerId').value = workerId;
  document.getElementById('workDate').value = new Date().toISOString().split('T')[0];
  showModal('dailyRecordModal');
}

// وظائف مساعدة للنوافذ المنبثقة
function showModal(modalId) {
  document.getElementById(modalId).style.display = 'block';
}

function closeModal(modalId) {
  document.getElementById(modalId).style.display = 'none';
}

// إظهار الإشعارات
function showNotification(message, type = 'success') {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;
  notification.textContent = message;

  document.body.appendChild(notification);

  setTimeout(() => {
    notification.remove();
  }, 3000);
}
